#!/usr/bin/ruby

require 'optparse'
require 'google/ads/google_ads'
require 'memory_profiler'

def get_campaigns(customer_id)
  # GoogleAdsClient will read a config file from
  # ENV['HOME']/google_ads_config.rb when called without parameters
  client = Google::Ads::GoogleAds::GoogleAdsClient.new

  responses = client.service.google_ads.search_stream(
    customer_id: customer_id,
    query: 'SELECT campaign.id, campaign.name FROM campaign ORDER BY campaign.id',
  )

  responses.each do |response|
    response.results.each do |row|
      puts "Campaign with ID #{row.campaign.id} and name '#{row.campaign.name}' was found."
    end
  end
end

def add_campaigns(customer_id)
  # GoogleAdsClient will read a config file from
  # ENV['HOME']/google_ads_config.rb when called without parameters
  client = Google::Ads::GoogleAds::GoogleAdsClient.new

  # [START add_campaigns]
  # Create a budget, which can be shared by multiple campaigns.
  campaign_budget = client.resource.campaign_budget do |cb|
    cb.name = "Interplanetary Budget #{(Time.new.to_f * 1000).to_i}"
    cb.delivery_method = :STANDARD
    cb.amount_micros = 500000
  end

  operation = client.operation.create_resource.campaign_budget(campaign_budget)

  # Add budget.
  return_budget = client.service.campaign_budget.mutate_campaign_budgets(
    customer_id: customer_id,
    operations: [operation],
  )
  # [END add_campaigns]

  # [START add_campaigns_1]
  # Create campaign.
  campaign = client.resource.campaign do |c|
    c.name = "Interplanetary Cruise #{(Time.new.to_f * 1000).to_i}"
    c.advertising_channel_type = :SEARCH

    # Recommendation: Set the campaign to PAUSED when creating it to prevent
    # the ads from immediately serving. Set to ENABLED once you've added
    # targeting and the ads are ready to serve.
    c.status = :PAUSED

    # Set the bidding strategy and budget.
    c.manual_cpc = client.resource.manual_cpc
    c.campaign_budget = return_budget.results.first.resource_name

    # Set the campaign network options.
    c.network_settings = client.resource.network_settings do |ns|
      ns.target_google_search = true
      ns.target_search_network = true
      ns.target_content_network = false
      ns.target_partner_search_network = false
    end

    # Optional: Set the start date.
    c.start_date = DateTime.parse((Date.today + 1).to_s).strftime('%Y%m%d')

    # Optional: Set the end date.
    c.end_date = DateTime.parse((Date.today.next_year).to_s).strftime('%Y%m%d')
  end
  # [END add_campaigns_1]

  # Create the operation.
  campaign_operation = client.operation.create_resource.campaign(campaign)

  # Add the campaign.
  response = client.service.campaign.mutate_campaigns(
    customer_id: customer_id,
    operations: [campaign_operation],
  )

  puts "Created campaign #{response.results.first.resource_name}."
end

if __FILE__ == $0
  report = MemoryProfiler.report do
    1.times{ get_campaigns('9211913182') }
  end

  report.pretty_print(to_file: 'get_campaign_1x.log')
end

